@@ -13,7 +13,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 $| = 1;
 
@@ -265,7 +265,12 @@ sub listen {
             my $bb = Test::BrewBuild->new(%opts);
             $bb->log()->file(\$self->{log}) if ! $self->{log_to_stdout};
             $bb->instance_remove if $opts{remove};
-            $bb->instance_install($opts{install}) if $opts{install};
+            if ($opts{install}){
+                $bb->instance_install($opts{install});
+            }
+            elsif ($opts{new}){
+                $bb->instance_install($opts{new});
+            }
 
             if ($opts{notest}){
                 $log->_5("no tests run due to --notest flag set");
@@ -306,6 +311,9 @@ sub listen {
 
             Storable::nstore_fd($res, $dispatch);
             chdir '..';
+
+            $self->{log} = '';
+            shutdown($dispatch, 1);
         }
     }
     $sock->close();
